*--- Routine to combine data and calculate beetle season effect (Aug 29, 2019) Version 14 ---*

cd "..."

graph set window fontface "Times New Roman"		
graph set window fontfacesans "Times New Roman"	

local k europe
local j point
use "season_current_`k'_`j'.dta", replace	

collapse (sum) pop_*, by(ragweed_`j' ctry_iso)	

	local list_var pop_general pop_rpop // pop_rsensit pop_sensit
	foreach var of local list_var{
		rename `var' `var'_current
	}
	merge m:m ragweed_`j' using "season_effect_`k'_`j'.dta", keep (1 3) nogen
	
	local list_var pop_general pop_rpop // pop_rsensit pop_sensit
	foreach var of local list_var{
		rename `var' `var'_effect
		replace `var'_effect = 0 if `var'_effect == .
		replace `var'_current = 0 if `var'_current == .
	}
	
	g n = _n
	qui sum n 
	
	local list_h pop_general_current pop_rpop_current pop_general_effect pop_rpop_effect // pop_rsensit_current pop_sensit_current pop_general_effect pop_rpop_effect pop_rsensit_effect pop_sensit_effect
	foreach h of local list_h {
		replace `h' = 0 if `h'==.
		egen tot = sum(`h')
		qui sum n 
		forvalues g = 2 / `=r(max)'{
			qui replace `h' = `h' +`h'[`g'-1] in `g' 
		}

		*g total = sum(`h')
		replace `h' = (1-`h'/tot)*100 
		drop tot
	}

*--- interpolate marginal change for values in between observations ---*

tsset ragweed_`j'
tsfill, full
local list_h pop_general_current pop_rpop_current pop_general_effect pop_rpop_effect // pop_rsensit_current pop_sensit_current pop_general_effect pop_rpop_effect pop_rsensit_effect pop_sensit_effect
foreach h of local list_h {
	mipolate `h' ragweed_`j', gen(`h'_ipol) pchip
}

*--- illustrate relationship (general population) ---*

label var  pop_general_current "Current ragweed exposure"
label var  pop_general_effect "Predicted future ragweed exposure"
	
twoway (line pop_general_current pop_general_effect ragweed_`j', lcolor(gs3 gs6) lpattern(shortdash dash)) ///
	,yscale(range(0 100)) ///
	legend(span title("") position(6) rows(1) region(lcolor(white))) ///
	xtitle("Seasonal pollen integral (in 1,000)", height(5)) ytitle("Share of population (in percent)") ///
	xlabel(0 "0" 2500 "2.5" 5000 "5" 7500 "7.5" 10000 "10", angle(0)) ///
	ylabel(0 20 40 60 80 100, angle(0)) subtitle("(a) General population", ring(3) pos(12) margin(medium)) ///
	graphregion(color(white) margin(medium)) plotregion(margin(zero)) xsize(2) ysize(2)
	
graph save "season_effect_general.gph", replace	

*--- illustrate relationship (ragweed sensitized population) ---*
	
twoway (line pop_rpop_current pop_rpop_effect ragweed_`j', lcolor(gs3 gs6) lpattern(shortdash dash)) ///
	,yscale(range(0 100)) ///
	legend(span title("") position(6) rows(1) region(lcolor(white))) ///
	xtitle("Seasonal pollen integral (in 1,000)", height(5)) ytitle("Share of population (in percent)") ///
	xlabel(0 "0" 2500 "2.5" 5000 "5" 7500 "7.5" 10000 "10", angle(0)) ///
	ylabel(0 20 40 60 80 100, angle(0)) subtitle("(b) Ragweed sensitised population", ring(3) pos(12) margin(medium)) ///
	graphregion(color(white) margin(medium)) plotregion(margin(zero)) xsize(2) ysize(2)
	
graph save "season_effect_rpop.gph", replace	

grc1leg "season_effect_general.gph" "season_effect_rpop.gph", legendfrom("season_effect_general.gph") graphregion(color(white) margin(medium)) plotregion(margin(zero)) 

graph export "season_beetle_effect_distribution.pdf", replace	
